@@ -3,9 +3,11 @@ Main interface for sagemaker-a2i-runtime service type definitions.
 
 Usage::
 
-    from mypy_boto3.sagemaker_a2i_runtime.type_defs import HumanLoopOutputTypeDef
+    ```python
+    from mypy_boto3_sagemaker_a2i_runtime.type_defs import HumanLoopOutputTypeDef
 
     data: HumanLoopOutputTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
